unit UModuleZdechovNET;

{$mode delphi}

interface

uses
  Classes, SysUtils, UModularSystem, SpecializedDictionary;

type

  { TModuleZdechovNET }

  TModuleZdechovNET = class(TModule)
  public
    constructor Create(Owner: TComponent); override;
    destructor Destroy; override;
    procedure Start; override;
    procedure Stop; override;
    procedure Install; override;
    procedure Uninstall; override;
    procedure Upgrade; override;
  end;


implementation

uses
  UCore, USqlDatabase, UXmlClasses, UHtmlClasses, UUtils,
  UInternetPage, UHostingPage, UHistoryPage, UDocumentsPage, UVoIPPage,
  ULinksPage, UPlansPage, UServerInfoPage, UWebCamPage,
  UNetworkPage, UAboutPage, UContactPage, UProjectsPage;

{ TModuleZdechovNET }

constructor TModuleZdechovNET.Create(Owner: TComponent);
begin
  inherited;
  Identification := 'ZdechovNET';
  Title := 'ZdechovNET web';
  Version := '1.0';
  License := 'GNU/LGPL v3';
  Author := 'Chronosoft';
end;

destructor TModuleZdechovNET.Destroy;
begin
  inherited Destroy;
end;

procedure TModuleZdechovNET.Start;
begin
  with Core.Pages do begin
    RegisterPage(TInternetPage, InternetPage, 'internet');
    RegisterPage(THostingPage, HostingPage, 'hosting');
    RegisterPage(THistoryPage, HistoryPage, 'historie');
    RegisterPage(TDocumentsPage, DocumentsPage, 'dokumenty');
    RegisterPage(TVoIPPage, VoIPPage, 'voip');
    RegisterPage(TLinksPage, LinksPage, 'odkazy');
    RegisterPage(TContactPage, ContactPage, 'kontakt');
    RegisterPage(TServerInfoPage, ServerInfoPage, 'serverinfo');
    RegisterPage(TWebCamPage, WebCamPage, 'kamery');
    RegisterPage(TPlansPage, PlansPage, 'plany');
    RegisterPage(TNetworkPage, NetworkPage, 'sit');
    RegisterPage(TProjectsPage, ProjectsPage, 'projekty');
    RegisterPage(TAboutPage, AboutPage, '');
  end;
  inherited;
end;

procedure TModuleZdechovNET.Stop;
begin
  inherited Stop;
  with Core.Pages do begin
    UnregisterPage('internet');
    UnregisterPage('hosting');
    UnregisterPage('historie');
    UnregisterPage('dokumenty');
    UnregisterPage('voip');
    UnregisterPage('odkazy');
    UnregisterPage('kontakt');
    UnregisterPage('serverinfo');
    UnregisterPage('kamery');
    UnregisterPage('plany');
    UnregisterPage('sit');
    UnregisterPage('projekty');
    UnregisterPage('');
  end;
end;

procedure TModuleZdechovNET.Install;
var
  DbRows: TDbRows;
  Data: TDictionaryStringString;
begin
  try
    DbRows := TDbRows.Create;
    Data := TDictionaryStringString.Create;

    Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `VPSHosting` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) NOT NULL,' +
    '  `Memory` varchar(255) NOT NULL,' +
    '  `Space` varchar(255) NOT NULL,' +
    '  `Internet` varchar(255) NOT NULL,' +
    '  `CPU` varchar(255) NOT NULL,' +
    '  `Price` int(11) NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;');

    Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `History` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Date` date NOT NULL,' +
    '  `Text` text COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `Webcam` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) CHARACTER SET utf8 COLLATE utf8_czech_ci NOT NULL,' +
    '  `Description` text CHARACTER SET utf8 COLLATE utf8_czech_ci NOT NULL,' +
    '  `ImageName` varchar(255) CHARACTER SET utf8 COLLATE utf8_czech_ci NOT NULL,' +
    '  `ImageURL` varchar(255) CHARACTER SET utf8 COLLATE utf8_czech_ci NOT NULL,' +
    '  `ImagePeriod` int(11) NOT NULL,' +
    '  `Width` int(11) NOT NULL,' +
    '  `Height` int(11) NOT NULL,' +
    '  `Enabled` int(11) NOT NULL DEFAULT "1",' +
    '  `DeviceType` varchar(255) NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;');

    Core.CommonDatabase.Query(DbRows,
    '  CREATE TABLE IF NOT EXISTS `Plans` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `TimeCreate` datetime NOT NULL,' +
    '  `TimeFinished` datetime DEFAULT NULL,' +
    '  `Description` text COLLATE utf8_czech_ci NOT NULL,' +
    '  `Conclusion` text COLLATE utf8_czech_ci NOT NULL,' +
    '  `Public` int(11) NOT NULL DEFAULT "0",' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `TimeCreate` (`TimeCreate`),' +
    '  KEY `TimeFinished` (`TimeFinished`)' +
    ') ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

  finally
    Data.Free;
    DbRows.Free;
  end;

  inherited Install;
end;

procedure TModuleZdechovNET.Uninstall;
var
  DbRows: TDbRows;
begin
  inherited Uninstall;
  try
    DbRows := TDbRows.Create;
    Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `Plans`');
    Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `Webcam`');
    Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `VPSHosting`');
    Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `History`');
  finally
    DbRows.Free;
  end;
end;

procedure TModuleZdechovNET.Upgrade;
begin
  inherited Upgrade;
end;

end.

